@@ -18,15 +18,14 @@ from .. import util
 
 def gen_colors(img):
     """Generate a colorscheme using Colorz."""
+    # pylint: disable=not-callable
     raw_colors = colorz.colorz(img, n=6, bold_add=0)
     return [util.rgb_to_hex([*color[0]]) for color in raw_colors]
 
 
 def adjust(cols, light):
     """Create palette."""
-    bg = util.blend_color("#555555", cols[1])
-
-    raw_colors = [bg, *cols, "#FFFFFF",
+    raw_colors = [cols[0], *cols, "#FFFFFF",
                   "#333333", *cols, "#FFFFFF"]
 
     return colors.generic_adjust(raw_colors, light)
