@@ -65,7 +65,7 @@ def generic_adjust(colors, light):
         colors[15] = colors[7]
 
     else:
-        colors[0] = util.darken_color(colors[0], 0.75)
+        colors[0] = util.darken_color(colors[0], 0.80)
         colors[7] = util.lighten_color(colors[0], 0.75)
         colors[8] = util.lighten_color(colors[0], 0.25)
         colors[15] = colors[7]
@@ -123,12 +123,7 @@ def get(img, light=False, backend="wal", cache_dir=CACHE_DIR, sat=""):
     cache_file = os.path.join(*cache_name)
 
     if os.path.isfile(cache_file):
-        # Disable logging in theme.file().
-        logger = logging.getLogger()
-        logger.disabled = True
         colors = theme.file(cache_file)
-        logger.disabled = False
-
         colors["alpha"] = util.Color.alpha_num
         logging.info("Found cached colorscheme.")
 
