@@ -22,19 +22,17 @@ def set_special(index, color, iterm_name="h", alpha=100):
 
 def set_color(index, color):
     """Convert a hex color to a text color sequence."""
-    if OS == "Darwin":
-        return "\033]P%x%s\033\\" % (index, color.strip("#"))
+    if OS == "Darwin" and index < 20:
+        return "\033]P%1x%s\033\\" % (index, color.strip("#"))
 
     return "\033]4;%s;%s\033\\" % (index, color)
 
 
 def set_iterm_tab_color(color):
     """Set iTerm2 tab/window color"""
-    return """
-    \033]6;1;bg;red;brightness;%s\a
-    \033]6;1;bg;green;brightness;%s\a
-    \033]6;1;bg;blue;brightness;%s\a
-    """ % (*util.hex_to_rgb(color),)
+    return ("\033]6;1;bg;red;brightness;%s\a"
+            "\033]6;1;bg;green;brightness;%s\a"
+            "\033]6;1;bg;blue;brightness;%s\a") % (*util.hex_to_rgb(color),)
 
 
 def create_sequences(colors):
@@ -56,21 +54,8 @@ def create_sequences(colors):
         set_special(13, colors["special"]["foreground"], "l"),
         set_special(17, colors["special"]["foreground"], "l"),
         set_special(19, colors["special"]["background"], "l"),
-        set_color(232, colors["special"]["background"])
-    ])
-
-    # This escape sequence doesn't work in VTE terminals and their parsing of
-    # unknown sequences is garbage so we need to use some escape sequence
-    # M A G I C to hide the output.
-    # \033[s                 # Save cursor position.
-    # \033[1000H             # Move the cursor off screen.
-    # \033[8m                # Conceal text.
-    # \033]708;#000000\033\\ # Garbage sequence.
-    # \033[u                 # Restore cursor position.
-    sequences.extend([
-        "\033[s\033[1000H\033[8m%s\033[u" %
-        set_special(708, colors["special"]["background"], "h", alpha),
-        set_special(13, colors["special"]["cursor"], "l")
+        set_color(232, colors["special"]["background"]),
+        set_color(256, colors["special"]["foreground"])
     ])
 
     if OS == "Darwin":
